#
# spec file for package libsignal-protocol-c
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define c_lib libsignal-protocol-c2
Name:           libsignal-protocol-c
Version:        2.3.3
Release:        1.17
Summary:        Signal Protocol C Library
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/signalapp/libsignal-protocol-c/
Source:         https://github.com/signalapp/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  check-devel >= 0.9.10
BuildRequires:  cmake >= 2.8.4
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl) >= 1.0

%description
The Signal Protocol is a ratcheting forward secrecy protocol that works in synchronous and asynchronous messaging environments.

%package -n libsignal-protocol-c-devel
Summary:        Development files for libsignal-protocol-c
Group:          Development/Libraries/C and C++
Requires:       %{c_lib} = %{version}

%description -n libsignal-protocol-c-devel
Development files and headers for libsignal-protocol-c

%package -n %{c_lib}
Summary:        Signal Protocol C Library
Group:          System/Libraries

%description -n %{c_lib}
The libsignal-protocol-c library is a forward secrecy protocol library written in C.

%prep
%setup -q

%build
%cmake \
    -DBUILD_TESTING=ON
%if %suse_version > 1500
%cmake_build
%else
%make_jobs
%endif

%install
%cmake_install

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%post -n %{c_lib} -p /sbin/ldconfig
%postun -n %{c_lib} -p /sbin/ldconfig

%files -n %{c_lib}
%license LICENSE
%doc README.md
%{_libdir}/libsignal-protocol-c.so.2
%{_libdir}/libsignal-protocol-c.so.2.3.3

%files devel
%dir %{_includedir}/signal
%{_includedir}/signal/*.h
%{_libdir}/libsignal-protocol-c.so
%{_libdir}/pkgconfig/libsignal-protocol-c.pc

%changelog
* Mon Mar 30 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.3.3:
  * Add limits.h include to provide INT_MAX
  * Introduce srand_deterministic to match OpenBSD (#120)
  * Test for endianness during CMake setup
  * Fix leaks in session_cipher get functions
- Remove fix_bigendian.patch: upstreamed
* Wed Feb 27 2019 Adam Mizerski <adam@mizerski.pl>
- Added patch fix_bigendian.patch
  (https://github.com/signalapp/libsignal-protocol-c/issues/124)
* Tue Feb 26 2019 Adam Mizerski <adam@mizerski.pl>
- Removed patch libsignal-protocol-c-2.3.2-lib_ver.patch
  This was the only change applied in tarball (see changelog below).
* Tue Feb 26 2019 mvetter@suse.com
- Update tarball. On new URL seems to be different.
* Tue Feb 26 2019 Adam Mizerski <adam@mizerski.pl>
- Build and run tests
- Update url
* Mon May 14 2018 mvetter@suse.com
- Add libsignal-protocol-c-2.3.2-lib_ver.patch:
  Use 2.3.2 lib version.
  See https://github.com/signalapp/libsignal-protocol-c/pull/110
* Mon May 14 2018 mvetter@suse.com
- Update to 2.3.2:
  * Update curve25519 code based on upstream changes
  * Added support for building against OpenSSL 1.1
  * Add ability to generate fingerprints from a collection of identity keys
  * Add support for identity fingerprint format v1
  * Update to latest protobuf definition for fingerprints
  * Provide a pkg-config file for libsignal-protocol-c
  * Explicitly require check 0.9.10+ for unit tests
  * Various bug fixes
  * For full list see:
  https://github.com/signalapp/libsignal-protocol-c/compare/v2.3.1...v2.3.2
* Fri Mar 31 2017 mvetter@suse.com
- Remove libsignal-protocol-c-math-lib-shared-lib.patch:
  Contained in new upstream release
- Update to 2.3.1
* Fri Mar 31 2017 mvetter@suse.com
- Create seperate proper lib package
* Thu Mar 30 2017 mvetter@suse.com
- Remove: libsignal-protocol-c-link-math.patch:
- Add libsignal-protocol-c-math-lib-shared-lib.patch:
  Upstream added its own version of the mathlib patch, see
  https://github.com/WhisperSystems/libsignal-protocol-c/issues/57
  Additionally I requested library versioning, see:
  https://github.com/WhisperSystems/libsignal-protocol-c/issues/59
* Thu Mar 30 2017 mvetter@suse.com
- Initial package for openSUSE in version 2.3.0
- Adding libsignal-protocol-c-link-math.patch:
  Link with Math library. Otherwise does not build
